@@ -1,6 +1,6 @@
 package WWW::Google::Contacts::Photo;
 {
-    $WWW::Google::Contacts::Photo::VERSION = '0.37';
+    $WWW::Google::Contacts::Photo::VERSION = '0.38';
 }
 
 use Moose;
@@ -98,3 +98,40 @@ no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 __END__
+
+=head1 SYNOPSIS
+
+    use WWW::Google::Contacts;
+
+    my $google = WWW::Google::Contacts->new( username => "your.username", password => "your.password" );
+
+    my $contacts = $google->contacts;
+
+    while ( my $contact = $contacts->next ) {
+       print "You got a friend called " . $contact->full_name . "\n";
+
+       if ( $contact->photo->exists ) {
+          print "And you got a photo of this friend\n";
+          # Save the picture to disk!
+          $contact->photo->to_file( "/opt/images/" . $contact->full_name . ".jpg" );
+       } else {
+          # Upload a picture for this contact
+          $contact->photo->from_file( "/opt/images/" . $contact->full_name . ".jpg" );
+          # Remember to update Google
+          $contact->photo->update();
+       }
+    }
+
+
+=head1 AUTHOR
+
+  Magnus Erixzon <magnus@erixzon.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010-2013 by Magnus Erixzon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=cut
